/****************************************************************************
** Meta object code from reading C++ file 'mpv_proxy.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.1)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../backends/mpv/mpv_proxy.h"
#include <QtGui/qtextcursor.h>
#include <QtGui/qscreen.h>
#include <QtNetwork/QSslError>
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'mpv_proxy.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.1. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3dmr8MpvProxyE_t {};
} // unnamed namespace

template <> constexpr inline auto dmr::MpvProxy::qt_create_metaobjectdata<qt_meta_tag_ZN3dmr8MpvProxyE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "dmr::MpvProxy",
        "has_mpv_events",
        "",
        "crashCheck",
        "play",
        "pauseResume",
        "stop",
        "seekForward",
        "nSecs",
        "seekBackward",
        "seekAbsolute",
        "nPos",
        "volumeUp",
        "volumeDown",
        "changeVolume",
        "nVol",
        "toggleMute",
        "setMute",
        "bMute",
        "handle_mpv_events",
        "stepBurstScreenshot",
        "slotStateChanged"
    };

    QtMocHelpers::UintData qt_methods {
        // Signal 'has_mpv_events'
        QtMocHelpers::SignalData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Signal 'crashCheck'
        QtMocHelpers::SignalData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'play'
        QtMocHelpers::SlotData<void()>(4, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'pauseResume'
        QtMocHelpers::SlotData<void()>(5, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'stop'
        QtMocHelpers::SlotData<void()>(6, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'seekForward'
        QtMocHelpers::SlotData<void(int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'seekBackward'
        QtMocHelpers::SlotData<void(int)>(9, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 },
        }}),
        // Slot 'seekAbsolute'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 11 },
        }}),
        // Slot 'volumeUp'
        QtMocHelpers::SlotData<void()>(12, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'volumeDown'
        QtMocHelpers::SlotData<void()>(13, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'changeVolume'
        QtMocHelpers::SlotData<void(int)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 15 },
        }}),
        // Slot 'toggleMute'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setMute'
        QtMocHelpers::SlotData<void(bool)>(17, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 18 },
        }}),
        // Slot 'handle_mpv_events'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'stepBurstScreenshot'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'slotStateChanged'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessProtected, QMetaType::Void),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<MpvProxy, qt_meta_tag_ZN3dmr8MpvProxyE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject dmr::MpvProxy::staticMetaObject = { {
    QMetaObject::SuperData::link<Backend::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr8MpvProxyE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr8MpvProxyE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3dmr8MpvProxyE_t>.metaTypes,
    nullptr
} };

void dmr::MpvProxy::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<MpvProxy *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->has_mpv_events(); break;
        case 1: _t->crashCheck(); break;
        case 2: _t->play(); break;
        case 3: _t->pauseResume(); break;
        case 4: _t->stop(); break;
        case 5: _t->seekForward((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->seekBackward((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->seekAbsolute((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 8: _t->volumeUp(); break;
        case 9: _t->volumeDown(); break;
        case 10: _t->changeVolume((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 11: _t->toggleMute(); break;
        case 12: _t->setMute((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 13: _t->handle_mpv_events(); break;
        case 14: _t->stepBurstScreenshot(); break;
        case 15: _t->slotStateChanged(); break;
        default: ;
        }
    }
    if (_c == QMetaObject::IndexOfMethod) {
        if (QtMocHelpers::indexOfMethod<void (MpvProxy::*)()>(_a, &MpvProxy::has_mpv_events, 0))
            return;
        if (QtMocHelpers::indexOfMethod<void (MpvProxy::*)()>(_a, &MpvProxy::crashCheck, 1))
            return;
    }
}

const QMetaObject *dmr::MpvProxy::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *dmr::MpvProxy::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3dmr8MpvProxyE_t>.strings))
        return static_cast<void*>(this);
    return Backend::qt_metacast(_clname);
}

int dmr::MpvProxy::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = Backend::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 16)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 16;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 16)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 16;
    }
    return _id;
}

// SIGNAL 0
void dmr::MpvProxy::has_mpv_events()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void dmr::MpvProxy::crashCheck()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
